# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddPartyAsyncRequest(_message.Message):
    __slots__ = ("party_id", "synchronizer_id", "source_participant_uid", "serial")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    synchronizer_id: str
    source_participant_uid: str
    serial: int
    def __init__(self, party_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., source_participant_uid: _Optional[str] = ..., serial: _Optional[int] = ...) -> None: ...

class AddPartyAsyncResponse(_message.Message):
    __slots__ = ("add_party_request_id",)
    ADD_PARTY_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    add_party_request_id: str
    def __init__(self, add_party_request_id: _Optional[str] = ...) -> None: ...

class GetAddPartyStatusRequest(_message.Message):
    __slots__ = ("add_party_request_id",)
    ADD_PARTY_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    add_party_request_id: str
    def __init__(self, add_party_request_id: _Optional[str] = ...) -> None: ...

class GetAddPartyStatusResponse(_message.Message):
    __slots__ = ("party_id", "synchronizer_id", "source_participant_uid", "target_participant_uid", "status")
    class Status(_message.Message):
        __slots__ = ("proposal_processed", "agreement_accepted", "topology_authorized", "connection_established", "replicating_acs", "completed", "error")
        class ProposalProcessed(_message.Message):
            __slots__ = ("topology_serial",)
            TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
            topology_serial: int
            def __init__(self, topology_serial: _Optional[int] = ...) -> None: ...
        class AgreementAccepted(_message.Message):
            __slots__ = ("sequencer_uid", "topology_serial")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            topology_serial: int
            def __init__(self, sequencer_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ...) -> None: ...
        class TopologyAuthorized(_message.Message):
            __slots__ = ("sequencer_uid", "topology_serial", "timestamp")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            topology_serial: int
            timestamp: _timestamp_pb2.Timestamp
            def __init__(self, sequencer_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        class ConnectionEstablished(_message.Message):
            __slots__ = ("sequencer_uid", "topology_serial", "timestamp")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            topology_serial: int
            timestamp: _timestamp_pb2.Timestamp
            def __init__(self, sequencer_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        class ReplicatingAcs(_message.Message):
            __slots__ = ("sequencer_uid", "topology_serial", "timestamp", "contracts_replicated")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            CONTRACTS_REPLICATED_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            topology_serial: int
            timestamp: _timestamp_pb2.Timestamp
            contracts_replicated: int
            def __init__(self, sequencer_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contracts_replicated: _Optional[int] = ...) -> None: ...
        class Completed(_message.Message):
            __slots__ = ("sequencer_uid", "topology_serial", "timestamp", "contracts_replicated")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            CONTRACTS_REPLICATED_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            topology_serial: int
            timestamp: _timestamp_pb2.Timestamp
            contracts_replicated: int
            def __init__(self, sequencer_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contracts_replicated: _Optional[int] = ...) -> None: ...
        class Error(_message.Message):
            __slots__ = ("error_message", "status_prior_to_error")
            ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
            STATUS_PRIOR_TO_ERROR_FIELD_NUMBER: _ClassVar[int]
            error_message: str
            status_prior_to_error: GetAddPartyStatusResponse.Status
            def __init__(self, error_message: _Optional[str] = ..., status_prior_to_error: _Optional[_Union[GetAddPartyStatusResponse.Status, _Mapping]] = ...) -> None: ...
        PROPOSAL_PROCESSED_FIELD_NUMBER: _ClassVar[int]
        AGREEMENT_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
        TOPOLOGY_AUTHORIZED_FIELD_NUMBER: _ClassVar[int]
        CONNECTION_ESTABLISHED_FIELD_NUMBER: _ClassVar[int]
        REPLICATING_ACS_FIELD_NUMBER: _ClassVar[int]
        COMPLETED_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        proposal_processed: GetAddPartyStatusResponse.Status.ProposalProcessed
        agreement_accepted: GetAddPartyStatusResponse.Status.AgreementAccepted
        topology_authorized: GetAddPartyStatusResponse.Status.TopologyAuthorized
        connection_established: GetAddPartyStatusResponse.Status.ConnectionEstablished
        replicating_acs: GetAddPartyStatusResponse.Status.ReplicatingAcs
        completed: GetAddPartyStatusResponse.Status.Completed
        error: GetAddPartyStatusResponse.Status.Error
        def __init__(self, proposal_processed: _Optional[_Union[GetAddPartyStatusResponse.Status.ProposalProcessed, _Mapping]] = ..., agreement_accepted: _Optional[_Union[GetAddPartyStatusResponse.Status.AgreementAccepted, _Mapping]] = ..., topology_authorized: _Optional[_Union[GetAddPartyStatusResponse.Status.TopologyAuthorized, _Mapping]] = ..., connection_established: _Optional[_Union[GetAddPartyStatusResponse.Status.ConnectionEstablished, _Mapping]] = ..., replicating_acs: _Optional[_Union[GetAddPartyStatusResponse.Status.ReplicatingAcs, _Mapping]] = ..., completed: _Optional[_Union[GetAddPartyStatusResponse.Status.Completed, _Mapping]] = ..., error: _Optional[_Union[GetAddPartyStatusResponse.Status.Error, _Mapping]] = ...) -> None: ...
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    TARGET_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    synchronizer_id: str
    source_participant_uid: str
    target_participant_uid: str
    status: GetAddPartyStatusResponse.Status
    def __init__(self, party_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., source_participant_uid: _Optional[str] = ..., target_participant_uid: _Optional[str] = ..., status: _Optional[_Union[GetAddPartyStatusResponse.Status, _Mapping]] = ...) -> None: ...

class ExportAcsTargetSynchronizer(_message.Message):
    __slots__ = ("target_synchronizer_id",)
    TARGET_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    target_synchronizer_id: str
    def __init__(self, target_synchronizer_id: _Optional[str] = ...) -> None: ...

class ExportAcsRequest(_message.Message):
    __slots__ = ("party_ids", "synchronizer_id", "ledger_offset", "contract_synchronizer_renames")
    class ContractSynchronizerRenamesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ExportAcsTargetSynchronizer
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ExportAcsTargetSynchronizer, _Mapping]] = ...) -> None: ...
    PARTY_IDS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    LEDGER_OFFSET_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_SYNCHRONIZER_RENAMES_FIELD_NUMBER: _ClassVar[int]
    party_ids: _containers.RepeatedScalarFieldContainer[str]
    synchronizer_id: str
    ledger_offset: int
    contract_synchronizer_renames: _containers.MessageMap[str, ExportAcsTargetSynchronizer]
    def __init__(self, party_ids: _Optional[_Iterable[str]] = ..., synchronizer_id: _Optional[str] = ..., ledger_offset: _Optional[int] = ..., contract_synchronizer_renames: _Optional[_Mapping[str, ExportAcsTargetSynchronizer]] = ...) -> None: ...

class ExportAcsResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ExportAcsAtTimestampRequest(_message.Message):
    __slots__ = ("party_ids", "synchronizer_id", "topology_transaction_effective_time")
    PARTY_IDS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TRANSACTION_EFFECTIVE_TIME_FIELD_NUMBER: _ClassVar[int]
    party_ids: _containers.RepeatedScalarFieldContainer[str]
    synchronizer_id: str
    topology_transaction_effective_time: _timestamp_pb2.Timestamp
    def __init__(self, party_ids: _Optional[_Iterable[str]] = ..., synchronizer_id: _Optional[str] = ..., topology_transaction_effective_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ExportAcsAtTimestampResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .party_management_service_pb2 import AddPartyAsyncRequest, AddPartyAsyncResponse, ExportAcsAtTimestampRequest, ExportAcsAtTimestampResponse, ExportAcsRequest, ExportAcsResponse, GetAddPartyStatusRequest, GetAddPartyStatusResponse

__all__ = [
    "PartyManagementServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PartyManagementServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PartyManagementServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PartyManagementServiceAsyncStub: ...  # type: ignore
    def AddPartyAsync(self, __1: AddPartyAsyncRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AddPartyAsyncResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AddPartyAsyncResponse]]: ...
    def GetAddPartyStatus(self, __1: GetAddPartyStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetAddPartyStatusResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetAddPartyStatusResponse]]: ...
    def ExportAcs(self, __1: ExportAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[ExportAcsResponse], _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsResponse]]: ...
    def ExportAcsAtTimestamp(self, __1: ExportAcsAtTimestampRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[ExportAcsAtTimestampResponse], _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsAtTimestampResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyManagementServiceBlockingStub(PartyManagementServiceStub):
    def AddPartyAsync(self, __1: AddPartyAsyncRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddPartyAsyncResponse: ...
    def GetAddPartyStatus(self, __1: GetAddPartyStatusRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetAddPartyStatusResponse: ...
    def ExportAcs(self, __1: ExportAcsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsResponse]: ...
    def ExportAcsAtTimestamp(self, __1: ExportAcsAtTimestampRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsAtTimestampResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyManagementServiceAsyncStub(PartyManagementServiceStub):
    def AddPartyAsync(self, __1: AddPartyAsyncRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AddPartyAsyncResponse]: ...  # type: ignore
    def GetAddPartyStatus(self, __1: GetAddPartyStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetAddPartyStatusResponse]: ...  # type: ignore
    def ExportAcs(self, __1: ExportAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsResponse]: ...  # type: ignore
    def ExportAcsAtTimestamp(self, __1: ExportAcsAtTimestampRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsAtTimestampResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from .....admin.participant.v30 import active_contract_pb2 as _active_contract_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PartyReplicationInstruction(_message.Message):
    __slots__ = ("max_counter",)
    MAX_COUNTER_FIELD_NUMBER: _ClassVar[int]
    max_counter: int
    def __init__(self, max_counter: _Optional[int] = ...) -> None: ...

class PartyReplicationSourceMessage(_message.Message):
    __slots__ = ("acs_chunk", "source_participant_is_ready", "end_of_acs")
    class AcsChunk(_message.Message):
        __slots__ = ("chunk_counter", "contracts")
        CHUNK_COUNTER_FIELD_NUMBER: _ClassVar[int]
        CONTRACTS_FIELD_NUMBER: _ClassVar[int]
        chunk_counter: int
        contracts: _containers.RepeatedCompositeFieldContainer[_active_contract_pb2.ActiveContractOld]
        def __init__(self, chunk_counter: _Optional[int] = ..., contracts: _Optional[_Iterable[_Union[_active_contract_pb2.ActiveContractOld, _Mapping]]] = ...) -> None: ...
    class SourceParticipantIsReady(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class EndOfACS(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    ACS_CHUNK_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PARTICIPANT_IS_READY_FIELD_NUMBER: _ClassVar[int]
    END_OF_ACS_FIELD_NUMBER: _ClassVar[int]
    acs_chunk: PartyReplicationSourceMessage.AcsChunk
    source_participant_is_ready: PartyReplicationSourceMessage.SourceParticipantIsReady
    end_of_acs: PartyReplicationSourceMessage.EndOfACS
    def __init__(self, acs_chunk: _Optional[_Union[PartyReplicationSourceMessage.AcsChunk, _Mapping]] = ..., source_participant_is_ready: _Optional[_Union[PartyReplicationSourceMessage.SourceParticipantIsReady, _Mapping]] = ..., end_of_acs: _Optional[_Union[PartyReplicationSourceMessage.EndOfACS, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/reassignment_id.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/reassignment_id.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/reassignment_id.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\x80\x01\n\x0eReassignmentId\x12\x34\n\x16source_synchronizer_id\x18\x01 \x01(\tR\x14sourceSynchronizerId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.reassignment_id_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_REASSIGNMENTID']._serialized_start=152
  _globals['_REASSIGNMENTID']._serialized_end=280
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/update_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/daml/ledger/api/v2/update_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import offset_checkpoint_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_offset__checkpoint__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import topology_transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_topology__transaction__pb2
from . import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+com/daml/ledger/api/v2/update_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a.com/daml/ledger/api/v2/offset_checkpoint.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a\x31\x63om/daml/ledger/api/v2/topology_transaction.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"\xa0\x02\n\x11GetUpdatesRequest\x12\'\n\x0f\x62\x65gin_exclusive\x18\x01 \x01(\x03R\x0e\x62\x65ginExclusive\x12(\n\rend_inclusive\x18\x02 \x01(\x03H\x00R\x0c\x65ndInclusive\x88\x01\x01\x12\x41\n\x06\x66ilter\x18\x03 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFilterR\x06\x66ilter\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\x12I\n\rupdate_format\x18\x05 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormatB\x10\n\x0e_end_inclusive\"\xee\x02\n\x12GetUpdatesResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12W\n\x11offset_checkpoint\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpoint\x12`\n\x14topology_transaction\x18\x04 \x01(\x0b\x32+.com.daml.ledger.api.v2.TopologyTransactionH\x00R\x13topologyTransactionB\x08\n\x06update\"\x9d\x02\n\x16GetUpdateTreesResponse\x12T\n\x10transaction_tree\x18\x01 \x01(\x0b\x32\'.com.daml.ledger.api.v2.TransactionTreeH\x00R\x0ftransactionTree\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12W\n\x11offset_checkpoint\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpointB\x08\n\x06update\"\xc0\x01\n\x1dGetTransactionByOffsetRequest\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\x12-\n\x12requesting_parties\x18\x02 \x03(\tR\x11requestingParties\x12X\n\x12transaction_format\x18\x03 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x11transactionFormat\"\xc1\x01\n\x19GetTransactionByIdRequest\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12-\n\x12requesting_parties\x18\x02 \x03(\tR\x11requestingParties\x12X\n\x12transaction_format\x18\x03 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x11transactionFormat\"g\n\x1aGetTransactionTreeResponse\x12I\n\x0btransaction\x18\x01 \x01(\x0b\x32\'.com.daml.ledger.api.v2.TransactionTreeR\x0btransaction\"_\n\x16GetTransactionResponse\x12\x45\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionR\x0btransaction\"}\n\x18GetUpdateByOffsetRequest\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\x12I\n\rupdate_format\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormat\"~\n\x14GetUpdateByIdRequest\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12I\n\rupdate_format\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormat\"\x94\x02\n\x11GetUpdateResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12`\n\x14topology_transaction\x18\x03 \x01(\x0b\x32+.com.daml.ledger.api.v2.TopologyTransactionH\x00R\x13topologyTransactionB\x08\n\x06update2\xc6\x07\n\rUpdateService\x12\x65\n\nGetUpdates\x12).com.daml.ledger.api.v2.GetUpdatesRequest\x1a*.com.daml.ledger.api.v2.GetUpdatesResponse0\x01\x12m\n\x0eGetUpdateTrees\x12).com.daml.ledger.api.v2.GetUpdatesRequest\x1a..com.daml.ledger.api.v2.GetUpdateTreesResponse0\x01\x12\x87\x01\n\x1aGetTransactionTreeByOffset\x12\x35.com.daml.ledger.api.v2.GetTransactionByOffsetRequest\x1a\x32.com.daml.ledger.api.v2.GetTransactionTreeResponse\x12\x7f\n\x16GetTransactionTreeById\x12\x31.com.daml.ledger.api.v2.GetTransactionByIdRequest\x1a\x32.com.daml.ledger.api.v2.GetTransactionTreeResponse\x12\x7f\n\x16GetTransactionByOffset\x12\x35.com.daml.ledger.api.v2.GetTransactionByOffsetRequest\x1a..com.daml.ledger.api.v2.GetTransactionResponse\x12w\n\x12GetTransactionById\x12\x31.com.daml.ledger.api.v2.GetTransactionByIdRequest\x1a..com.daml.ledger.api.v2.GetTransactionResponse\x12p\n\x11GetUpdateByOffset\x12\x30.com.daml.ledger.api.v2.GetUpdateByOffsetRequest\x1a).com.daml.ledger.api.v2.GetUpdateResponse\x12h\n\rGetUpdateById\x12,.com.daml.ledger.api.v2.GetUpdateByIdRequest\x1a).com.daml.ledger.api.v2.GetUpdateResponseB\x91\x01\n\x16\x63om.daml.ledger.api.v2B\x17UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.update_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\027UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_GETUPDATESREQUEST']._serialized_start=305
  _globals['_GETUPDATESREQUEST']._serialized_end=593
  _globals['_GETUPDATESRESPONSE']._serialized_start=596
  _globals['_GETUPDATESRESPONSE']._serialized_end=962
  _globals['_GETUPDATETREESRESPONSE']._serialized_start=965
  _globals['_GETUPDATETREESRESPONSE']._serialized_end=1250
  _globals['_GETTRANSACTIONBYOFFSETREQUEST']._serialized_start=1253
  _globals['_GETTRANSACTIONBYOFFSETREQUEST']._serialized_end=1445
  _globals['_GETTRANSACTIONBYIDREQUEST']._serialized_start=1448
  _globals['_GETTRANSACTIONBYIDREQUEST']._serialized_end=1641
  _globals['_GETTRANSACTIONTREERESPONSE']._serialized_start=1643
  _globals['_GETTRANSACTIONTREERESPONSE']._serialized_end=1746
  _globals['_GETTRANSACTIONRESPONSE']._serialized_start=1748
  _globals['_GETTRANSACTIONRESPONSE']._serialized_end=1843
  _globals['_GETUPDATEBYOFFSETREQUEST']._serialized_start=1845
  _globals['_GETUPDATEBYOFFSETREQUEST']._serialized_end=1970
  _globals['_GETUPDATEBYIDREQUEST']._serialized_start=1972
  _globals['_GETUPDATEBYIDREQUEST']._serialized_end=2098
  _globals['_GETUPDATERESPONSE']._serialized_start=2101
  _globals['_GETUPDATERESPONSE']._serialized_end=2377
  _globals['_UPDATESERVICE']._serialized_start=2380
  _globals['_UPDATESERVICE']._serialized_end=3346
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/common.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/topology/admin/v30/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/digitalasset/canton/topology/admin/v30/common.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x03\n\x14TopologyTransactions\x12[\n\x05items\x18\x01 \x03(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v30.TopologyTransactions.ItemR\x05items\x1a\x9f\x02\n\x04Item\x12\x38\n\tsequenced\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransaction\x12.\n\x10rejection_reason\x18\x05 \x01(\tH\x00R\x0frejectionReason\x88\x01\x01\x42\x13\n\x11_rejection_reason\"\x8a\x03\n\x07StoreId\x12`\n\nauthorized\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.topology.admin.v30.StoreId.AuthorizedH\x00R\nauthorized\x12\x66\n\x0csynchronizer\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.StoreId.SynchronizerH\x00R\x0csynchronizer\x12]\n\ttemporary\x18\x03 \x01(\x0b\x32=.com.digitalasset.canton.topology.admin.v30.StoreId.TemporaryH\x00R\ttemporary\x1a\x0c\n\nAuthorized\x1a\x1e\n\x0cSynchronizer\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a\x1f\n\tTemporary\x12\x12\n\x04name\x18\x01 \x01(\tR\x04nameB\x07\n\x05storeB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_TOPOLOGYTRANSACTIONS']._serialized_start=137
  _globals['_TOPOLOGYTRANSACTIONS']._serialized_end=542
  _globals['_TOPOLOGYTRANSACTIONS_ITEM']._serialized_start=255
  _globals['_TOPOLOGYTRANSACTIONS_ITEM']._serialized_end=542
  _globals['_STOREID']._serialized_start=545
  _globals['_STOREID']._serialized_end=939
  _globals['_STOREID_AUTHORIZED']._serialized_start=853
  _globals['_STOREID_AUTHORIZED']._serialized_end=865
  _globals['_STOREID_SYNCHRONIZER']._serialized_start=867
  _globals['_STOREID_SYNCHRONIZER']._serialized_end=897
  _globals['_STOREID_TEMPORARY']._serialized_start=899
  _globals['_STOREID_TEMPORARY']._serialized_end=930
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .bft_ordering_service_pb2 import BftOrderingServiceReceiveRequest, BftOrderingServiceReceiveResponse, PingRequest, PingResponse

__all__ = [
    "BftOrderingServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class BftOrderingServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _BftOrderingServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _BftOrderingServiceAsyncStub: ...  # type: ignore
    def Ping(self, __1: PingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[PingResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, PingResponse]]: ...
    def Receive(self, __1: _typing.Iterable[BftOrderingServiceReceiveRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[BftOrderingServiceReceiveResponse], _grpc_aio.UnaryStreamCall[_typing.Any, BftOrderingServiceReceiveResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _BftOrderingServiceBlockingStub(BftOrderingServiceStub):
    def Ping(self, __1: PingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PingResponse: ...
    def Receive(self, __1: _typing.Iterable[BftOrderingServiceReceiveRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[BftOrderingServiceReceiveResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _BftOrderingServiceAsyncStub(BftOrderingServiceStub):
    def Ping(self, __1: PingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PingResponse]: ...  # type: ignore
    def Receive(self, __1: _typing.Iterable[BftOrderingServiceReceiveRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, BftOrderingServiceReceiveResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/party_management_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/party_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/admin/participant/v30/party_management_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x01\n\x14\x41\x64\x64PartyAsyncRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\x16\n\x06serial\x18\x04 \x01(\rR\x06serial\"H\n\x15\x41\x64\x64PartyAsyncResponse\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"K\n\x18GetAddPartyStatusRequest\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"\x81\x13\n\x19GetAddPartyStatusResponse\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\x34\n\x16target_participant_uid\x18\x04 \x01(\tR\x14targetParticipantUid\x12g\n\x06status\x18\x05 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x06status\x1a\xca\x10\n\x06Status\x12\x92\x01\n\x12proposal_processed\x18\x01 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ProposalProcessedH\x00R\x11proposalProcessed\x12\x92\x01\n\x12\x61greement_accepted\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.AgreementAcceptedH\x00R\x11\x61greementAccepted\x12\x95\x01\n\x13topology_authorized\x18\x03 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.TopologyAuthorizedH\x00R\x12topologyAuthorized\x12\x9e\x01\n\x16\x63onnection_established\x18\x04 \x01(\x0b\x32\x65.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ConnectionEstablishedH\x00R\x15\x63onnectionEstablished\x12\x89\x01\n\x0freplicating_acs\x18\x05 \x01(\x0b\x32^.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ReplicatingAcsH\x00R\x0ereplicatingAcs\x12y\n\tcompleted\x18\x06 \x01(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.CompletedH\x00R\tcompleted\x12m\n\x05\x65rror\x18\x07 \x01(\x0b\x32U.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ErrorH\x00R\x05\x65rror\x1aU\n\x11ProposalProcessed\x12,\n\x0ftopology_serial\x18\x01 \x01(\rH\x00R\x0etopologySerial\x88\x01\x01\x42\x12\n\x10_topology_serial\x1az\n\x11\x41greementAccepted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12,\n\x0ftopology_serial\x18\x02 \x01(\rH\x00R\x0etopologySerial\x88\x01\x01\x42\x12\n\x10_topology_serial\x1a\x9c\x01\n\x12TopologyAuthorized\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\x9f\x01\n\x15\x43onnectionEstablished\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\xcb\x01\n\x0eReplicatingAcs\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x04 \x01(\rR\x13\x63ontractsReplicated\x1a\xc6\x01\n\tCompleted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x04 \x01(\rR\x13\x63ontractsReplicated\x1a\xb1\x01\n\x05\x45rror\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12\x82\x01\n\x15status_prior_to_error\x18\x02 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x12statusPriorToErrorB\x08\n\x06status\"S\n\x1b\x45xportAcsTargetSynchronizer\x12\x34\n\x16target_synchronizer_id\x18\x01 \x01(\tR\x14targetSynchronizerId\"\xc1\x03\n\x10\x45xportAcsRequest\x12\x1b\n\tparty_ids\x18\x01 \x03(\tR\x08partyIds\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12#\n\rledger_offset\x18\x03 \x01(\x03R\x0cledgerOffset\x12\xa4\x01\n\x1d\x63ontract_synchronizer_renames\x18\x04 \x03(\x0b\x32`.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.ContractSynchronizerRenamesEntryR\x1b\x63ontractSynchronizerRenames\x1a\x9a\x01\n ContractSynchronizerRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12`\n\x05value\x18\x02 \x01(\x0b\x32J.com.digitalasset.canton.admin.participant.v30.ExportAcsTargetSynchronizerR\x05value:\x02\x38\x01\")\n\x11\x45xportAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xce\x01\n\x1b\x45xportAcsAtTimestampRequest\x12\x1b\n\tparty_ids\x18\x01 \x03(\tR\x08partyIds\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12i\n#topology_transaction_effective_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR topologyTransactionEffectiveTime\"4\n\x1c\x45xportAcsAtTimestampResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk2\xa5\x05\n\x16PartyManagementService\x12\x9a\x01\n\rAddPartyAsync\x12\x43.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncResponse\x12\xa6\x01\n\x11GetAddPartyStatus\x12G.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse\x12\x90\x01\n\tExportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ExportAcsResponse0\x01\x12\xb1\x01\n\x14\x45xportAcsAtTimestamp\x12J.com.digitalasset.canton.admin.participant.v30.ExportAcsAtTimestampRequest\x1aK.com.digitalasset.canton.admin.participant.v30.ExportAcsAtTimestampResponse0\x01\x42^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.party_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_ADDPARTYASYNCREQUEST']._serialized_start=161
  _globals['_ADDPARTYASYNCREQUEST']._serialized_end=329
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_start=331
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_end=403
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_start=405
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_end=480
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_start=483
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_end=2916
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_start=794
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_end=2916
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_start=1789
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_end=1874
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_start=1876
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_end=1998
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_start=2001
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_end=2157
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_start=2160
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_end=2319
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_start=2322
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_end=2525
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_start=2528
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_end=2726
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_start=2729
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_end=2906
  _globals['_EXPORTACSTARGETSYNCHRONIZER']._serialized_start=2918
  _globals['_EXPORTACSTARGETSYNCHRONIZER']._serialized_end=3001
  _globals['_EXPORTACSREQUEST']._serialized_start=3004
  _globals['_EXPORTACSREQUEST']._serialized_end=3453
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_start=3299
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_end=3453
  _globals['_EXPORTACSRESPONSE']._serialized_start=3455
  _globals['_EXPORTACSRESPONSE']._serialized_end=3496
  _globals['_EXPORTACSATTIMESTAMPREQUEST']._serialized_start=3499
  _globals['_EXPORTACSATTIMESTAMPREQUEST']._serialized_end=3705
  _globals['_EXPORTACSATTIMESTAMPRESPONSE']._serialized_start=3707
  _globals['_EXPORTACSATTIMESTAMPRESPONSE']._serialized_end=3759
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_start=3762
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_end=4439
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/quorum.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/protocol/v30/quorum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1com/digitalasset/canton/protocol/v30/quorum.proto\x12$com.digitalasset.canton.protocol.v30\"\x96\x01\n\x06Quorum\x12n\n\x16party_index_and_weight\x18\x01 \x03(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.PartyIndexAndWeightR\x13partyIndexAndWeight\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold\"C\n\x13PartyIndexAndWeight\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weightBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.quorum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_QUORUM']._serialized_start=92
  _globals['_QUORUM']._serialized_end=242
  _globals['_PARTYINDEXANDWEIGHT']._serialized_start=244
  _globals['_PARTYINDEXANDWEIGHT']._serialized_end=311
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PackageReference(_message.Message):
    __slots__ = ("package_id", "package_name", "package_version")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    package_name: str
    package_version: str
    def __init__(self, package_id: _Optional[str] = ..., package_name: _Optional[str] = ..., package_version: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/daml_lf_1_17/daml_lf.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/daml/daml_lf_1_17/daml_lf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import daml_lf_1_pb2 as com_dot_daml_dot_daml__lf__1__17_dot_daml__lf__1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#com/daml/daml_lf_1_17/daml_lf.proto\x12\x0c\x64\x61ml_lf_1_17\x1a%com/daml/daml_lf_1_17/daml_lf_1.proto\"\x8e\x01\n\x0e\x41rchivePayload\x12\x14\n\x05minor\x18\x03 \x01(\tR\x05minor\x12\x33\n\tdaml_lf_1\x18\x02 \x01(\x0b\x32\x15.daml_lf_1_17.PackageH\x00R\x07\x64\x61mlLf1\x12\x1c\n\tdaml_lf_2\x18\x04 \x01(\x0cH\x00R\x07\x64\x61mlLf2B\x05\n\x03SumJ\x06\x08\x8fN\x10\x90NJ\x04\x08\x01\x10\x02\"x\n\x07\x41rchive\x12?\n\rhash_function\x18\x01 \x01(\x0e\x32\x1a.daml_lf_1_17.HashFunctionR\x0chashFunction\x12\x18\n\x07payload\x18\x03 \x01(\x0cR\x07payload\x12\x12\n\x04hash\x18\x04 \x01(\tR\x04hash*\x1a\n\x0cHashFunction\x12\n\n\x06SHA256\x10\x00\x42|\n\x15\x63om.daml.daml_lf_1_17ZDgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/daml_lf_1_17\xaa\x02\x1c\x43om.Daml.Daml_Lf_1_17.DamlLfb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.daml_lf_1_17.daml_lf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.daml.daml_lf_1_17ZDgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/daml_lf_1_17\252\002\034Com.Daml.Daml_Lf_1_17.DamlLf'
  _globals['_HASHFUNCTION']._serialized_start=359
  _globals['_HASHFUNCTION']._serialized_end=385
  _globals['_ARCHIVEPAYLOAD']._serialized_start=93
  _globals['_ARCHIVEPAYLOAD']._serialized_end=235
  _globals['_ARCHIVE']._serialized_start=237
  _globals['_ARCHIVE']._serialized_end=357
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import update_service_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2

GRPC_GENERATED_VERSION = '1.72.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/daml/ledger/api/v2/update_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UpdateServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUpdates = channel.unary_stream(
                '/com.daml.ledger.api.v2.UpdateService/GetUpdates',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesResponse.FromString,
                _registered_method=True)
        self.GetUpdateTrees = channel.unary_stream(
                '/com.daml.ledger.api.v2.UpdateService/GetUpdateTrees',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateTreesResponse.FromString,
                _registered_method=True)
        self.GetTransactionTreeByOffset = channel.unary_unary(
                '/com.daml.ledger.api.v2.UpdateService/GetTransactionTreeByOffset',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByOffsetRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionTreeResponse.FromString,
                _registered_method=True)
        self.GetTransactionTreeById = channel.unary_unary(
                '/com.daml.ledger.api.v2.UpdateService/GetTransactionTreeById',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByIdRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionTreeResponse.FromString,
                _registered_method=True)
        self.GetTransactionByOffset = channel.unary_unary(
                '/com.daml.ledger.api.v2.UpdateService/GetTransactionByOffset',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByOffsetRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionResponse.FromString,
                _registered_method=True)
        self.GetTransactionById = channel.unary_unary(
                '/com.daml.ledger.api.v2.UpdateService/GetTransactionById',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByIdRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionResponse.FromString,
                _registered_method=True)
        self.GetUpdateByOffset = channel.unary_unary(
                '/com.daml.ledger.api.v2.UpdateService/GetUpdateByOffset',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateByOffsetRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateResponse.FromString,
                _registered_method=True)
        self.GetUpdateById = channel.unary_unary(
                '/com.daml.ledger.api.v2.UpdateService/GetUpdateById',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateByIdRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateResponse.FromString,
                _registered_method=True)


class UpdateServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUpdates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdateTrees(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionTreeByOffset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionTreeById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionByOffset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdateByOffset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdateById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UpdateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUpdates': grpc.unary_stream_rpc_method_handler(
                    servicer.GetUpdates,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesResponse.SerializeToString,
            ),
            'GetUpdateTrees': grpc.unary_stream_rpc_method_handler(
                    servicer.GetUpdateTrees,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateTreesResponse.SerializeToString,
            ),
            'GetTransactionTreeByOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionTreeByOffset,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByOffsetRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionTreeResponse.SerializeToString,
            ),
            'GetTransactionTreeById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionTreeById,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByIdRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionTreeResponse.SerializeToString,
            ),
            'GetTransactionByOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionByOffset,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByOffsetRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionResponse.SerializeToString,
            ),
            'GetTransactionById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionById,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByIdRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionResponse.SerializeToString,
            ),
            'GetUpdateByOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpdateByOffset,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateByOffsetRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateResponse.SerializeToString,
            ),
            'GetUpdateById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpdateById,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateByIdRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.daml.ledger.api.v2.UpdateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.daml.ledger.api.v2.UpdateService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UpdateService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUpdates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetUpdates',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUpdateTrees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetUpdateTrees',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdatesRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateTreesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionTreeByOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetTransactionTreeByOffset',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByOffsetRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionTreeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionTreeById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetTransactionTreeById',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByIdRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionTreeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionByOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetTransactionByOffset',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByOffsetRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetTransactionById',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionByIdRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetTransactionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUpdateByOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetUpdateByOffset',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateByOffsetRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUpdateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.UpdateService/GetUpdateById',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateByIdRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_update__service__pb2.GetUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/signed_content.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/protocol/v30/signed_content.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9com/digitalasset/canton/protocol/v30/signed_content.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\"\xe4\x01\n\rSignedContent\x12\x1d\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00R\x07\x63ontent\x88\x01\x01\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\x12<\n\x18timestamp_of_signing_key\x18\x03 \x01(\x03H\x01R\x15timestampOfSigningKey\x88\x01\x01\x42\n\n\x08_contentB\x1b\n\x19_timestamp_of_signing_keyBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.signed_content_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_SIGNEDCONTENT']._serialized_start=149
  _globals['_SIGNEDCONTENT']._serialized_end=377
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="Identifier")


@_attrs_define
class Identifier:
    """
    Attributes:
        package_id (str):
        module_name (str):
        entity_name (str):
    """

    package_id: str
    module_name: str
    entity_name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        package_id = self.package_id

        module_name = self.module_name

        entity_name = self.entity_name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "packageId": package_id,
                "moduleName": module_name,
                "entityName": entity_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        package_id = d.pop("packageId")

        module_name = d.pop("moduleName")

        entity_name = d.pop("entityName")

        identifier = cls(
            package_id=package_id,
            module_name=module_name,
            entity_name=entity_name,
        )

        identifier.additional_properties = d
        return identifier

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
